@@ -27,6 +27,6 @@ async def handle_email_exists_api(api_implementation: APIInterface, api_options:
         raise_bad_input_exception('Please provide the email as a GET param')
 
     response = await api_implementation.email_exists_get(email, api_options)
-    api_options.response.set_content(response.to_json())
+    api_options.response.set_json_content(response.to_json())
 
     return api_options.response
