@@ -21,7 +21,8 @@ from .exceptions import raise_unauthorised_exception, raise_try_refresh_token_ex
 from .cookie_and_header import get_id_refresh_token_from_cookie, get_access_token_from_cookie, get_anti_csrf_header, \
     get_rid_header, get_refresh_token_from_cookie
 from . import session_functions
-from supertokens_python.utils import execute_in_background, FRAMEWORKS, frontend_has_interceptor, normalise_http_method
+from supertokens_python.utils import execute_in_background, FRAMEWORKS, frontend_has_interceptor, \
+    normalise_http_method, get_timestamp_ms
 
 if TYPE_CHECKING:
     from typing import Union, List
@@ -33,15 +34,17 @@ class HandshakeInfo:
 
     def __init__(self, info):
         self.access_token_blacklisting_enabled = info['accessTokenBlacklistingEnabled']
-        self.jwt_signing_public_key = info['jwtSigningPublicKey']
-        self.jwt_signing_public_key_expiry_time = info['jwtSigningPublicKeyExpiryTime']
+        self.raw_jwt_signing_public_key_list = None
         self.anti_csrf = info['antiCsrf']
         self.access_token_validity = info['accessTokenValidity']
         self.refresh_token_validity = info['refreshTokenValidity']
 
-    def update_jwt_signing_public_key_info(self, new_key, new_expiry):
-        self.jwt_signing_public_key = new_key
-        self.jwt_signing_public_key_expiry_time = new_expiry
+    def set_jwt_signing_public_key_list(self, updated_list: List):
+        self.raw_jwt_signing_public_key_list = updated_list
+
+    def get_jwt_signing_public_key_list(self) -> List:
+        time_now = get_timestamp_ms()
+        return [key for key in self.raw_jwt_signing_public_key_list if key['expiryTime'] > time_now]
 
 
 class RecipeImplementation(RecipeInterface):
@@ -62,8 +65,9 @@ class RecipeImplementation(RecipeInterface):
         except Exception:
             pass
 
-    async def get_handshake_info(self) -> HandshakeInfo:
-        if self.handshake_info is None:
+    async def get_handshake_info(self, force_refetch=False) -> HandshakeInfo:
+        if self.handshake_info is None or len(
+                self.handshake_info.get_jwt_signing_public_key_list()) == 0 or force_refetch:
             ProcessState.get_instance().add_state(
                 AllowedProcessStates.CALLING_SERVICE_IN_GET_HANDSHAKE_INFO)
             response = await self.querier.send_post_request(NormalisedURLPath('/recipe/handshake'), {})
@@ -71,18 +75,29 @@ class RecipeImplementation(RecipeInterface):
                 **response,
                 'antiCsrf': self.config.anti_csrf
             })
+
+            self.update_jwt_signing_public_key_info(response['jwtSigningPublicKeyList'],
+                                                    response['jwtSigningPublicKey'],
+                                                    response['jwtSigningPublicKeyExpiryTime'])
+
         return self.handshake_info
 
-    def update_jwt_signing_public_key_info(self, new_key, new_expiry):
-        if self.handshake_info is not None:
-            self.handshake_info.update_jwt_signing_public_key_info(
-                new_key, new_expiry)
+    def update_jwt_signing_public_key_info(self, key_list: Union[List, None], public_key: str, expiry_time: int):
+        if key_list is None:
+            key_list = [{
+                'publicKey': public_key,
+                'expiryTime': expiry_time,
+                'createdAt': get_timestamp_ms()
+            }]
 
-    async def create_new_session(self, request: any, user_id: str, jwt_payload: Union[dict, None] = None,
+        if self.handshake_info is not None:
+            self.handshake_info.set_jwt_signing_public_key_list(key_list)
+
+    async def create_new_session(self, request: any, user_id: str, access_token_payload: Union[dict, None] = None,
                                  session_data: Union[dict, None] = None) -> Session:
         if not hasattr(request, 'wrapper_used') or not request.wrapper_used:
             request = FRAMEWORKS[self.config.framework].wrap_request(request)
-        session = await session_functions.create_new_session(self, user_id, jwt_payload, session_data)
+        session = await session_functions.create_new_session(self, user_id, access_token_payload, session_data)
         access_token = session['accessToken']
         refresh_token = session['refreshToken']
         id_refresh_token = session['idRefreshToken']
@@ -109,7 +124,8 @@ class RecipeImplementation(RecipeInterface):
                                          'request as cookies?', False)
         access_token = get_access_token_from_cookie(request)
         if access_token is None:
-            if session_required is True or frontend_has_interceptor(request) or normalise_http_method(request.method()) == 'get':
+            if session_required is True or frontend_has_interceptor(request) or normalise_http_method(
+                    request.method()) == 'get':
                 raise_try_refresh_token_exception(
                     'Access token has expired. Please call the refresh API')
             return None
@@ -176,8 +192,8 @@ class RecipeImplementation(RecipeInterface):
     async def update_session_data(self, session_handle: str, new_session_data: dict) -> None:
         await session_functions.update_session_data(self, session_handle, new_session_data)
 
-    async def update_jwt_payload(self, session_handle: str, new_jwt_payload: dict) -> None:
-        await session_functions.update_jwt_payload(self, session_handle, new_jwt_payload)
+    async def update_access_token_payload(self, session_handle: str, new_access_token_payload: dict) -> None:
+        await session_functions.update_access_token_payload(self, session_handle, new_access_token_payload)
 
     async def get_access_token_lifetime_ms(self) -> int:
         return (await self.get_handshake_info()).access_token_validity
