@@ -24,8 +24,9 @@ from .exceptions import raise_unauthorised_exception
 
 
 class Session:
-    def __init__(self, recipe_implementation: RecipeImplementation, access_token, session_handle,
-                 user_id, access_token_payload):
+    def __init__(self, recipe_implementation: RecipeImplementation, access_token, session_handle, user_id,
+                 access_token_payload):
+        super().__init__()
         self.__recipe_implementation = recipe_implementation
         self.__access_token = access_token
         self.__session_handle = session_handle
