@@ -15,6 +15,8 @@
 from typing import Union, List
 
 from supertokens_python.async_to_sync_wrapper import sync
+from supertokens_python.recipe.openid.interfaces import CreateJwtResult, GetOpenIdDiscoveryConfigurationResult, \
+    GetJWKSResult
 from supertokens_python.recipe.session.asyncio import Session
 
 
@@ -64,3 +66,21 @@ def update_session_data(session_handle: str, new_session_data: dict) -> None:
 async def update_access_token_payload(session_handle: str, new_access_token_payload: dict) -> None:
     from supertokens_python.recipe.session.asyncio import update_access_token_payload as async_update_access_token_payload
     return sync(async_update_access_token_payload(session_handle, new_access_token_payload))
+
+
+async def create_jwt(payload: dict, validity_seconds: int = None) -> [CreateJwtResult, None]:
+    from supertokens_python.recipe.session.asyncio import \
+        create_jwt as async_create_jwt
+    return sync(async_create_jwt(payload, validity_seconds))
+
+
+async def get_jwks() -> [GetJWKSResult, None]:
+    from supertokens_python.recipe.session.asyncio import \
+        get_jwks as async_get_jwks
+    return sync(async_get_jwks())
+
+
+async def get_open_id_discovery_configuration() -> [GetOpenIdDiscoveryConfigurationResult, None]:
+    from supertokens_python.recipe.session.asyncio import \
+        get_open_id_discovery_configuration as async_get_open_id_discovery_configuration
+    return sync(async_get_open_id_discovery_configuration())
