@@ -11,6 +11,10 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from typing import Union
+
+from .utils import SignInAndUpFeature, InputOverrideConfig
+
 from .recipe import ThirdPartyRecipe
 from . import exceptions
 from .providers import (
@@ -21,7 +25,10 @@ from .providers import (
     Discord,
     GoogleWorkspaces
 )
+from ..emailverification.utils import InputEmailVerificationConfig
 
 
-def init(config=None):
-    return ThirdPartyRecipe.init(config)
+def init(sign_in_and_up_feature: SignInAndUpFeature,
+         email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
+         override: Union[InputOverrideConfig, None] = None):
+    return ThirdPartyRecipe.init(sign_in_and_up_feature, email_verification_feature, override)
