@@ -24,8 +24,9 @@ if TYPE_CHECKING:
 
 class Google(Provider):
     def __init__(self, client_id: str, client_secret: str, scope: List[str] = None,
-                 authorisation_redirect: Dict[str, Union[str, Callable[[BaseRequest], str]]] = None):
-        super().__init__('google', client_id)
+                 authorisation_redirect: Dict[str, Union[str, Callable[[BaseRequest], str]]] = None,
+                 is_default: bool = False):
+        super().__init__('google', client_id, is_default)
         default_scopes = ['https://www.googleapis.com/auth/userinfo.email']
         if scope is None:
             scope = default_scopes
