@@ -16,62 +16,54 @@ from __future__ import annotations
 from typing import List, Callable, TYPE_CHECKING, Union
 
 from .interfaces import RecipeInterface, APIInterface
-from .types import INPUT_SCHEMA
 from supertokens_python.exceptions import raise_bad_input_exception
 
 if TYPE_CHECKING:
     from .recipe import ThirdPartyRecipe
     from .provider import Provider
-from supertokens_python.utils import validate_the_structure_of_user_input
+from supertokens_python.recipe.emailverification.utils import (
+    InputEmailVerificationConfig, ParentRecipeEmailVerificationConfig,
+    OverrideConfig as EmailVerificationOverrideConfig
+)
 from jwt import PyJWKClient, decode
 
 
 class SignInAndUpFeature:
     def __init__(self, providers: List[Provider]):
+        if len(providers) == 0:
+            raise_bad_input_exception('thirdparty recipe requires atleast 1 provider to be passed in '
+                                      'sign_in_and_up_feature.providers config')
+        default_providers_set = set()
+        all_providers_set = set()
+
+        for provider in providers:
+            provider_id = provider.id
+            all_providers_set.add(provider_id)
+            is_default = provider.is_default
+
+            if not is_default:
+                # if this id is not being used by any other provider, we treat this as the is_default
+                other_providers_with_same_id = list(filter(lambda p: p.id == provider_id and provider != p, providers))
+                if len(other_providers_with_same_id) == 0:
+                    # we treat this as the isDefault now.
+                    is_default = True
+            if is_default:
+                if provider_id in default_providers_set:
+                    raise_bad_input_exception(
+                        'You have provided multiple third party providers that have the id: "' + provider_id + '" '
+                                                                                                               'and '
+                                                                                                               'are '
+                                                                                                               'marked as "is_default: True". Please only mark one of them as is_default.')
+                default_providers_set.add(provider_id)
+
+        if len(default_providers_set) != len(all_providers_set):
+            # this means that there is no provider marked as is_default
+            raise_bad_input_exception(
+                'The providers array has multiple entries for the same third party provider. Please '
+                'mark one of them as the default one by using "is_default: true".')
         self.providers = providers
 
 
-def validate_and_normalise_sign_in_and_up_config(
-        config=None) -> SignInAndUpFeature:
-    if config is None:
-        config = {}
-    providers = config['providers']
-    if providers is None or len(providers) == 0:
-        raise_bad_input_exception('thirdparty recipe requires atleast 1 provider to be passed in '
-                                  'sign_in_and_up_feature.providers config')
-
-    # we check if there are multiple providers with the same id that have isDefault as true.
-    # In this case, we want to throw an error..
-
-    default_providers_set = set()
-    all_providers_set = set()
-
-    for provider in providers:
-        provider_id = provider.id
-        all_providers_set.add(provider_id)
-        is_default = provider.is_default
-
-        if not is_default:
-            # if this id is not being used by any other provider, we treat this as the is_default
-            other_providers_with_same_id = list(filter(lambda p: p.id == provider_id and provider != p, providers))
-            if len(other_providers_with_same_id) == 0:
-                # we treat this as the isDefault now.
-                is_default = True
-        if is_default:
-            if provider_id in default_providers_set:
-                raise_bad_input_exception(
-                    'You have provided multiple third party providers that have the id: "' + provider_id + '" '
-                    'and are marked as "is_default: True". Please only mark one of them as is_default.')
-            default_providers_set.add(provider_id)
-
-    if len(default_providers_set) != len(all_providers_set):
-        # this means that there is no provider marked as is_default
-        raise_bad_input_exception('The providers array has multiple entries for the same third party provider. Please '
-                                  'mark one of them as the default one by using "is_default: true".')
-
-    return SignInAndUpFeature(providers)
-
-
 def email_verification_create_and_send_custom_email(
         recipe: ThirdPartyRecipe, create_and_send_custom_email):
     async def func(user, link):
@@ -95,30 +87,38 @@ def email_verification_get_email_verification_url(
 
 
 def validate_and_normalise_email_verification_config(
-        recipe: ThirdPartyRecipe, config=None, override=None):
+        recipe: ThirdPartyRecipe, config: Union[InputEmailVerificationConfig, None], override: InputOverrideConfig)\
+        -> ParentRecipeEmailVerificationConfig:
     create_and_send_custom_email = None
     get_email_verification_url = None
     if config is None:
-        config = {}
-    if override is None:
-        override = {}
-    if 'create_and_send_custom_email' in config:
-        create_and_send_custom_email = email_verification_create_and_send_custom_email(recipe, config[
-            'create_and_send_custom_email'])
-    if 'get_email_verification_url' in config:
+        config = InputEmailVerificationConfig()
+    if config.create_and_send_custom_email is not None:
+        create_and_send_custom_email = email_verification_create_and_send_custom_email(recipe, config.create_and_send_custom_email)
+    if config.get_email_verification_url is not None:
         get_email_verification_url = email_verification_get_email_verification_url(recipe,
-                                                                                   config['get_email_verification_url'])
-    return {
-        'get_email_for_user_id': recipe.get_email_for_user_id,
-        'create_and_send_custom_email': create_and_send_custom_email,
-        'get_email_verification_url': get_email_verification_url,
-        'override': override
-    }
+                                                                                   config.get_email_verification_url)
+
+    return ParentRecipeEmailVerificationConfig(
+        get_email_for_user_id=recipe.get_email_for_user_id,
+        create_and_send_custom_email=create_and_send_custom_email,
+        get_email_verification_url=get_email_verification_url,
+        override=override.email_verification_feature
+    )
+
+
+class InputOverrideConfig:
+    def __init__(self, functions: Union[Callable[[RecipeInterface], RecipeInterface], None] = None,
+                 apis: Union[Callable[[APIInterface], APIInterface], None] = None,
+                 email_verification_feature: Union[EmailVerificationOverrideConfig, None] = None):
+        self.functions = functions
+        self.apis = apis
+        self.email_verification_feature = email_verification_feature
 
 
 class OverrideConfig:
-    def __init__(self, functions: Union[Callable[[RecipeInterface], RecipeInterface], None],
-                 apis: Union[Callable[[APIInterface], APIInterface], None]):
+    def __init__(self, functions: Union[Callable[[RecipeInterface], RecipeInterface], None] = None,
+                 apis: Union[Callable[[APIInterface], APIInterface], None] = None):
         self.functions = functions
         self.apis = apis
 
@@ -126,7 +126,7 @@ class OverrideConfig:
 class ThirdPartyConfig:
     def __init__(self,
                  sign_in_and_up_feature: SignInAndUpFeature,
-                 email_verification_feature: any,
+                 email_verification_feature: ParentRecipeEmailVerificationConfig,
                  override: OverrideConfig):
         self.sign_in_and_up_feature = sign_in_and_up_feature
         self.email_verification_feature = email_verification_feature
@@ -134,23 +134,18 @@ class ThirdPartyConfig:
 
 
 def validate_and_normalise_user_input(
-        recipe: ThirdPartyRecipe, config) -> ThirdPartyConfig:
-    validate_the_structure_of_user_input(
-        config, INPUT_SCHEMA, 'thirdparty recipe', recipe)
-    sign_in_and_up_feature = validate_and_normalise_sign_in_and_up_config(
-        config['sign_in_and_up_feature'] if 'sign_in_and_up_feature' in config else None)
+        recipe: ThirdPartyRecipe,
+        sign_in_and_up_feature: SignInAndUpFeature,
+        email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
+        override: Union[InputOverrideConfig, None] = None) -> ThirdPartyConfig:
+    if override is None:
+        override = InputOverrideConfig()
     email_verification_feature = validate_and_normalise_email_verification_config(
         recipe,
-        config['email_verification_feature'] if 'email_verification_feature' in config else None,
-        config['override']['email_verification_feature'] if 'override' in config and 'email_verification_feature' in
-                                                            config['override'] else None)
-    override_functions = config['override']['functions'] if 'override' in config and 'functions' in config[
-        'override'] else None
-    override_apis = config['override']['apis'] if 'override' in config and 'apis' in config[
-        'override'] else None
-    override = OverrideConfig(override_functions, override_apis)
-    return ThirdPartyConfig(sign_in_and_up_feature,
-                            email_verification_feature, override)
+        email_verification_feature, override)
+    return ThirdPartyConfig(sign_in_and_up_feature, email_verification_feature,
+                            OverrideConfig(functions=override.functions, apis=override.apis)
+                            )
 
 
 def find_right_provider(
