@@ -14,14 +14,16 @@
 import json
 import os
 import sys
+from typing import Literal, Union
 
 import uvicorn
 from starlette.requests import Request
 
 from supertokens_python.framework.fastapi import Middleware
+from supertokens_python.recipe.session import InputErrorHandlers
 from supertokens_python.recipe.session.framework.fastapi import verify_session
 
-from supertokens_python import init, get_all_cors_headers, Supertokens
+from supertokens_python import init, get_all_cors_headers, Supertokens, SupertokensConfig, InputAppInfo
 from supertokens_python.recipe import session
 from supertokens_python.recipe.session.asyncio import Session, revoke_all_sessions_for_user, create_new_session, SessionRecipe
 from fastapi import FastAPI, Depends
@@ -36,6 +38,9 @@ app = FastAPI(debug=True)
 app.add_middleware(Middleware)
 os.environ.setdefault('SUPERTOKENS_ENV', 'testing')
 
+last_set_enable_anti_csrf = True
+last_set_enable_jwt = False
+
 
 class Test:
     no_of_times_refresh_called_during_test = 0
@@ -84,6 +89,23 @@ def apis_override_session(param):
     return param
 
 
+def functions_override_session(param):
+    original_create_new_session = param.create_new_session
+
+    async def create_new_session_custom(request: any, user_id: str, access_token_payload: Union[dict, None] = None,
+                                        session_data: Union[dict, None] = None) -> Session:
+        if access_token_payload is None:
+            access_token_payload = {}
+        access_token_payload = {
+            **access_token_payload,
+            'customClaim': 'customValue'
+        }
+        return await original_create_new_session(request, user_id, access_token_payload, session_data)
+    param.create_new_session = create_new_session_custom
+
+    return param
+
+
 def get_app_port():
     argvv = sys.argv
     for i in range(0, len(argvv)):
@@ -93,32 +115,55 @@ def get_app_port():
     return '8080'
 
 
-def config(enable_anti_csrf: bool):
-    return {
-        'supertokens': {
-            'connection_uri': "http://localhost:9000",
-        },
-        'framework': 'fastapi',
-        'app_info': {
-            'app_name': "SuperTokens Python SDK",
-            'api_domain': "0.0.0.0:" + get_app_port(),
-            'website_domain': "http://localhost.org:8080",
-        },
-        'recipe_list': [
-            session.init({
-                "error_handlers": {
-                    "on_unauthorised": unauthorised_f
-                },
-                "anti_csrf": "VIA_TOKEN" if enable_anti_csrf else "NONE",
-                "override": {
-                    'apis': apis_override_session
-                }
-            })],
-        'telemetry': False
-    }
+def config(enable_anti_csrf: bool, enable_jwt: bool, jwt_property_name: Union[str, None]):
+    anti_csrf: Literal['VIA_TOKEN', 'NONE'] = "NONE"
+    if enable_anti_csrf:
+        anti_csrf = "VIA_TOKEN"
+    if enable_jwt:
+        init(
+            supertokens_config=SupertokensConfig('http://localhost:9000'),
+            app_info=InputAppInfo(
+                app_name="SuperTokens Python SDK",
+                api_domain="0.0.0.0:" + get_app_port(),
+                website_domain="http://localhost.org:8080"
+            ),
+            framework='fastapi',
+            recipe_list=[session.init(
+                error_handlers=InputErrorHandlers(
+                    on_unauthorised=unauthorised_f
+                ),
+                anti_csrf=anti_csrf,
+                override=session.InputOverrideConfig(
+                    apis=apis_override_session,
+                    functions=functions_override_session
+                ),
+                jwt=session.JWTConfig(enable_jwt, jwt_property_name)
+            )],
+            telemetry=False
+        )
+    else:
+        init(
+            supertokens_config=SupertokensConfig('http://localhost:9000'),
+            app_info=InputAppInfo(
+                app_name="SuperTokens Python SDK",
+                api_domain="0.0.0.0:" + get_app_port(),
+                website_domain="http://localhost.org:8080"
+            ),
+            framework='fastapi',
+            recipe_list=[session.init(
+                error_handlers=InputErrorHandlers(
+                    on_unauthorised=unauthorised_f
+                ),
+                anti_csrf=anti_csrf,
+                override=session.InputOverrideConfig(
+                    apis=apis_override_session
+                )
+            )],
+            telemetry=False
+        )
 
 
-init(config(True))
+config(True, False, None)
 
 app.add_middleware(ExceptionMiddleware, handlers=app.exception_handlers)
 
@@ -141,8 +186,8 @@ def login_options():
 @app.post('/login')
 async def login(request: Request):
     user_id = (await request.json())['userId']
-    await create_new_session(request, user_id)
-    return PlainTextResponse(content=user_id)
+    _session = await create_new_session(request, user_id)
+    return PlainTextResponse(content=_session.get_user_id())
 
 
 @app.options("/beforeeach")
@@ -205,10 +250,10 @@ async def update_jwt(sess: Session = Depends(verify_session())):
 
 
 @app.post('/update-jwt')
-async def update_jwt_post(request: Request, session: Session = Depends(verify_session())):
-    await session.update_access_token_payload(await request.json())
+async def update_jwt_post(request: Request, _session: Session = Depends(verify_session())):
+    await _session.update_access_token_payload(await request.json())
     Test.increment_get_session()
-    return JSONResponse(content=session.get_access_token_payload(), headers={
+    return JSONResponse(content=_session.get_access_token_payload(), headers={
         'Cache-Control': 'no-cache, private'
     })
 
@@ -256,8 +301,8 @@ def logout_options():
 
 
 @app.post('/logout')
-async def logout(session: Session = Depends(verify_session())):
-    await session.revoke_session()
+async def logout(_session: Session = Depends(verify_session())):
+    await _session.revoke_session()
     return PlainTextResponse(content='success')
 
 
@@ -267,8 +312,8 @@ def revoke_all_options():
 
 
 @app.post('/revokeAll')
-async def revoke_all(session: Session = Depends(verify_session())):
-    await revoke_all_sessions_for_user(session.get_user_id())
+async def revoke_all(_session: Session = Depends(verify_session())):
+    await revoke_all_sessions_for_user(_session.get_user_id())
     return PlainTextResponse(content='success')
 
 
@@ -299,15 +344,36 @@ async def refresh(request: Request):
 
 @app.post('/setAntiCsrf')
 async def set_anti_csrf(request: Request):
+    global last_set_enable_anti_csrf
     json = await request.json()
     if "enableAntiCsrf" not in json:
         enable_csrf = True
     else:
         enable_csrf = json["enableAntiCsrf"]
+
+    last_set_enable_anti_csrf = enable_csrf
     if enable_csrf is not None:
         Supertokens.reset()
         SessionRecipe.reset()
-        init(config(enable_csrf))
+        config(enable_csrf, False, None)
+    return PlainTextResponse(content='success')
+
+
+@app.post('/setEnableJWT')
+async def set_enable_jwt(request: Request):
+    global last_set_enable_jwt
+    global last_set_enable_anti_csrf
+    json = await request.json()
+    if "enableJWT" not in json:
+        enable_jwt = False
+    else:
+        enable_jwt = json["enableJWT"]
+
+    last_set_enable_jwt = enable_jwt
+    if enable_jwt is not None:
+        Supertokens.reset()
+        SessionRecipe.reset()
+        config(last_set_enable_anti_csrf, enable_jwt, None)
     return PlainTextResponse(content='success')
 
 
@@ -374,6 +440,31 @@ def check_rid(request: Request):
     return PlainTextResponse('fail' if rid is None else 'success')
 
 
+@app.get('/featureFlags')
+def feature_flags(_: Request):
+    global last_set_enable_jwt
+
+    return JSONResponse({
+        'sessionJwt': last_set_enable_jwt
+    })
+
+
+@app.post('/reinitialiseBackendConfig')
+async def reinitialize(request: Request):
+    global last_set_enable_jwt
+    global last_set_enable_anti_csrf
+    json = await request.json()
+    if "jwtPropertyName" not in json:
+        jwt_property_name = None
+    else:
+        jwt_property_name = json["jwtPropertyName"]
+
+    Supertokens.reset()
+    SessionRecipe.reset()
+    config(last_set_enable_anti_csrf, last_set_enable_jwt, jwt_property_name)
+    return PlainTextResponse(content='')
+
+
 @app.options("/checkAllowCredentials")
 def check_allow_credentials_options():
     return send_options_api_response()
